==> ru-2.27.zip: ru/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%d attachments'] = 'Вложений: %d';
L10n::$locales['%d comments'] = 'Комментариев: %d';
L10n::$locales['%d trackbacks'] = 'Трекбеков: %d';
L10n::$locales['%s reactions'] = '%s реакций';
L10n::$locales['Access to content'] = 'Доступ к контенту';
L10n::$locales['Add a comment'] = 'Добавить комментарий';
L10n::$locales['Add ping'] = 'Добавить пинг';
L10n::$locales['Additionnal style directives'] = 'Директивы к дополнительному стилю';
L10n::$locales['All keywords'] = 'Все ключевые слова';
L10n::$locales['Archives'] = 'Архивы';
L10n::$locales['Attachments'] = 'Вложения';
L10n::$locales['Best of me'] = 'Лучшие';
L10n::$locales['Blog info'] = 'Информация о блоге';
L10n::$locales['Blog menu'] = 'Меню блога';
L10n::$locales['By'] = 'Кем';
L10n::$locales['By category'] = 'По категориям';
L10n::$locales['By date'] = 'По дате';
L10n::$locales['By tag'] = 'По тегу';
L10n::$locales['Categories'] = 'Категории';
L10n::$locales['Comment'] = 'Комментарий';
L10n::$locales['Comments'] = 'Комментарии';
L10n::$locales['Comments can be formatted using a simple wiki syntax.'] = 'Комментарии могут быть отформатированы, используя простой wiki-синтаксис.';
L10n::$locales['Comments feed'] = 'RSS комментариев';
L10n::$locales['Continue reading'] = 'Читать дальше';
L10n::$locales['Document not found'] = 'Документ не найден';
L10n::$locales['Email address'] = 'Email';
L10n::$locales['Email address is not valid'] = 'Неверный адрес email';
L10n::$locales['Entries feed'] = 'RSS записей';
L10n::$locales['Explore archives'] = 'Просмотреть архивы';
L10n::$locales['Extra menu'] = 'Extra menu';
L10n::$locales['From'] = 'От';
L10n::$locales['FromDay'] = 'С Дня';
L10n::$locales['Go to homepage'] = 'Перейти на главную страницу';
L10n::$locales['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML код отображается как текст, веб адреса автоматически преобразовываются.';
L10n::$locales['Home'] = 'Домой';
L10n::$locales['In'] = 'В';
L10n::$locales['Languages'] = 'Языки';
L10n::$locales['Links'] = 'Ссылки';
L10n::$locales['Name or nickname'] = 'Имя';
L10n::$locales['Next entry:'] = 'Следующая запись:';
L10n::$locales['On'] = 'В';
L10n::$locales['Page top'] = 'Верхняя страница';
L10n::$locales['Pagination'] = 'Пагинация';
L10n::$locales['Password needed'] = 'Необходим пароль';
L10n::$locales['Password:'] = 'Пароль:';
L10n::$locales['Permalink'] = 'Постоянная ссылка';
L10n::$locales['Powered by %s'] = 'Создано на %s';
L10n::$locales['Preview'] = 'Предпросмотр';
L10n::$locales['Previous entry:'] = 'Предыдущая запись:';
L10n::$locales['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Лента новостей RSS - это краткая подборка новостей блога. Она содержит записи или комментарии вместе со ссылками на полную версию, а также другие данные. Последние опубликованные записи могут быть прочитаны таким образом в приложении для <a href="http://en.wikipedia.org/wiki/Aggregator">чтения лент RSS</a>';
L10n::$locales['Read'] = 'Читать';
L10n::$locales['Remember me on this blog'] = 'Запомнить меня на этом блоге';
L10n::$locales['Required field'] = 'Обязательное поле';
L10n::$locales['Search'] = 'Поиск';
L10n::$locales['Send'] = 'Отправить';
L10n::$locales['Simply copy the following URL into your aggregator:'] = 'Копировать следующий URL в программу чтения новостей:';
L10n::$locales['Subcategories'] = 'Подкатегории';
L10n::$locales['Subscribe'] = 'Подписаться';
L10n::$locales['Subscribe to'] = 'Подписаться на';
L10n::$locales['Suggestions:'] = 'Предложения:';
L10n::$locales['The document you are looking for does not exist.'] = 'Документ, который вы ищете не существует.';
L10n::$locales['The list of recents posts is available'] = 'Список недавних сообщений доступен';
L10n::$locales['They posted on the same topic'] = 'Продолжение обсуждения';
L10n::$locales['This blog\'s comments Atom feed'] = 'Лента новостей Atom комментариев блога';
L10n::$locales['This category\'s comments Atom feed'] = 'Лента новостей Atom комментариев этой категории';
L10n::$locales['This category\'s entries Atom feed'] = 'Лента новостей Atom записей блога';
L10n::$locales['This post\'s comments Atom feed'] = 'Лента новостей Atom комментариев этой записи';
L10n::$locales['This post\'s comments feed'] = 'RSS комментариев этой записи';
L10n::$locales['To content'] = 'К содержимому';
L10n::$locales['To menu'] = 'К меню';
L10n::$locales['To search'] = 'В поиск';
L10n::$locales['Trackback URL'] = 'URL трекбека';
L10n::$locales['URL you\'ve tried has typos, or the page has been deleted or moved.'] = 'URL-адрес, который вы пытались опечатать, или страница была удалена или перемещена.';
L10n::$locales['Use search form'] = 'Использовать форму поиска';
L10n::$locales['Website'] = 'Вебсайт';
L10n::$locales['What is an RSS feed?'] = 'Что такое RSS ?';
L10n::$locales['You must give a password to access this area.'] = 'Нужно ввести пароль чтобы пройти далее.';
L10n::$locales['You must provide a comment'] = 'Введите ваш комментарий';
L10n::$locales['You must provide a valid email address.'] = 'Введите правильный email адрес.';
L10n::$locales['You must provide an author name'] = 'Укажите ваше имя';
L10n::$locales['Your comment'] = 'Ваш комментарий';
L10n::$locales['Your comment has been published.'] = 'Ваш комментарий опубликован.';
L10n::$locales['Your comment has been submitted and will be reviewed for publication.'] = 'Ваш комментарий сохранен и ожидает модерации.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'По вашему запросу <em>%1$s</em>получен результат<strong>%2$s</strong>';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'По вашему запросу <em>%1$s</em>получены результаты<strong>%2$s</strong>';
L10n::$locales['Your search for <em>%1$s</em> returned no result.'] = 'По запросу <em>%1$s</em>ничего не найлено.';
L10n::$locales['by'] = 'кем';
L10n::$locales['here'] = 'здесь';
L10n::$locales['in'] = 'в';
L10n::$locales['next entries'] = 'следующие записи';
L10n::$locales['no attachments'] = 'нет вложений';
L10n::$locales['no comments'] = 'нет комментариев';
L10n::$locales['no reactions'] = 'нет реакций';
L10n::$locales['no trackbacks'] = 'нет трекбеков';
L10n::$locales['of'] = 'из';
L10n::$locales['on'] = 'в';
L10n::$locales['one attachment'] = 'Одно вложение';
L10n::$locales['one comment'] = 'Один комментарий';
L10n::$locales['one reaction'] = 'одна реакция';
L10n::$locales['one trackback'] = 'Один трекбек';
L10n::$locales['optional'] = 'необязательно';
L10n::$locales['page'] = 'страница';
L10n::$locales['preview'] = 'предпросмотр';
L10n::$locales['previous entries'] = 'предыдущие записи';
L10n::$locales['reactions'] = 'реакции';
L10n::$locales['send'] = 'отправить';
L10n::$locales['toDay'] = 'до дня';

==> ru-2.29.zip: ru/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%d attachments'] = 'Вложений: %d';
L10n::$locales['%d comments'] = 'Комментариев: %d';
L10n::$locales['%d trackbacks'] = 'Трекбеков: %d';
L10n::$locales['%s reactions'] = '%s реакций';
L10n::$locales['Access to content'] = 'Доступ к контенту';
L10n::$locales['Add a comment'] = 'Добавить комментарий';
L10n::$locales['Add ping'] = 'Добавить пинг';
L10n::$locales['Additionnal style directives'] = 'Директивы к дополнительному стилю';
L10n::$locales['All keywords'] = 'Все ключевые слова';
L10n::$locales['Archives'] = 'Архивы';
L10n::$locales['Attachments'] = 'Вложения';
L10n::$locales['Best of me'] = 'Лучшие';
L10n::$locales['Blog info'] = 'Информация о блоге';
L10n::$locales['Blog menu'] = 'Меню блога';
L10n::$locales['By'] = 'Кем';
L10n::$locales['By category'] = 'По категориям';
L10n::$locales['By date'] = 'По дате';
L10n::$locales['By tag'] = 'По тегу';
L10n::$locales['Categories'] = 'Категории';
L10n::$locales['Comment'] = 'Комментарий';
L10n::$locales['Comments'] = 'Комментарии';
L10n::$locales['Comments can be formatted using a simple wiki syntax.'] = 'Комментарии могут быть отформатированы, используя простой wiki-синтаксис.';
L10n::$locales['Comments feed'] = 'RSS комментариев';
L10n::$locales['Continue reading'] = 'Читать дальше';
L10n::$locales['Document not found'] = 'Документ не найден';
L10n::$locales['Email address'] = 'Email';
L10n::$locales['Email address is not valid'] = 'Неверный адрес email';
L10n::$locales['Entries feed'] = 'RSS записей';
L10n::$locales['Explore archives'] = 'Просмотреть архивы';
L10n::$locales['Extra menu'] = 'Extra menu';
L10n::$locales['Fields followed by * are mandatory'] = 'Поля, отмеченные *, являются обязательными для заполнения';
L10n::$locales['From'] = 'От';
L10n::$locales['FromDay'] = 'С Дня';
L10n::$locales['Go to homepage'] = 'Перейти на главную страницу';
L10n::$locales['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML код отображается как текст, веб адреса автоматически преобразовываются.';
L10n::$locales['Home'] = 'Домой';
L10n::$locales['In'] = 'В';
L10n::$locales['Languages'] = 'Языки';
L10n::$locales['Links'] = 'Ссылки';
L10n::$locales['Name or nickname'] = 'Имя';
L10n::$locales['Next entry:'] = 'Следующая запись:';
L10n::$locales['On'] = 'В';
L10n::$locales['Page top'] = 'Верхняя страница';
L10n::$locales['Pagination'] = 'Пагинация';
L10n::$locales['Password needed'] = 'Необходим пароль';
L10n::$locales['Password:'] = 'Пароль:';
L10n::$locales['Permalink'] = 'Постоянная ссылка';
L10n::$locales['Powered by %s'] = 'Создано на %s';
L10n::$locales['Preview'] = 'Предпросмотр';
L10n::$locales['Previous entry:'] = 'Предыдущая запись:';
L10n::$locales['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Лента новостей RSS - это краткая подборка новостей блога. Она содержит записи или комментарии вместе со ссылками на полную версию, а также другие данные. Последние опубликованные записи могут быть прочитаны таким образом в приложении для <a href="http://en.wikipedia.org/wiki/Aggregator">чтения лент RSS</a>';
L10n::$locales['Read'] = 'Читать';
L10n::$locales['Remember me on this blog'] = 'Запомнить меня на этом блоге';
L10n::$locales['Required field'] = 'Обязательное поле';
L10n::$locales['Search'] = 'Поиск';
L10n::$locales['Send'] = 'Отправить';
L10n::$locales['Simply copy the following URL into your aggregator:'] = 'Копировать следующий URL в программу чтения новостей:';
L10n::$locales['Subcategories'] = 'Подкатегории';
L10n::$locales['Subscribe'] = 'Подписаться';
L10n::$locales['Subscribe to'] = 'Подписаться на';
L10n::$locales['Suggestions:'] = 'Предложения:';
L10n::$locales['The document you are looking for does not exist.'] = 'Документ, который вы ищете не существует.';
L10n::$locales['The list of recents posts is available'] = 'Список недавних сообщений доступен';
L10n::$locales['They posted on the same topic'] = 'Продолжение обсуждения';
L10n::$locales['This blog\'s comments Atom feed'] = 'Лента новостей Atom комментариев блога';
L10n::$locales['This category\'s comments Atom feed'] = 'Лента новостей Atom комментариев этой категории';
L10n::$locales['This category\'s entries Atom feed'] = 'Лента новостей Atom записей блога';
L10n::$locales['This post\'s comments Atom feed'] = 'Лента новостей Atom комментариев этой записи';
L10n::$locales['This post\'s comments feed'] = 'RSS комментариев этой записи';
L10n::$locales['To content'] = 'К содержимому';
L10n::$locales['To menu'] = 'К меню';
L10n::$locales['To search'] = 'В поиск';
L10n::$locales['Trackback URL'] = 'URL трекбека';
L10n::$locales['URL you\'ve tried has typos, or the page has been deleted or moved.'] = 'URL-адрес, который вы пытались опечатать, или страница была удалена или перемещена.';
L10n::$locales['Use search form'] = 'Использовать форму поиска';
L10n::$locales['Website'] = 'Вебсайт';
L10n::$locales['What is an RSS feed?'] = 'Что такое RSS ?';
L10n::$locales['You must give a password to access this area.'] = 'Нужно ввести пароль чтобы пройти далее.';
L10n::$locales['You must provide a comment'] = 'Введите ваш комментарий';
L10n::$locales['You must provide a valid email address.'] = 'Введите правильный email адрес.';
L10n::$locales['You must provide an author name'] = 'Укажите ваше имя';
L10n::$locales['Your comment'] = 'Ваш комментарий';
L10n::$locales['Your comment has been published.'] = 'Ваш комментарий опубликован.';
L10n::$locales['Your comment has been submitted and will be reviewed for publication.'] = 'Ваш комментарий сохранен и ожидает модерации.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'По вашему запросу <em>%1$s</em>получен результат<strong>%2$s</strong>';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'По вашему запросу <em>%1$s</em>получены результаты<strong>%2$s</strong>';
L10n::$locales['Your search for <em>%1$s</em> returned no result.'] = 'По запросу <em>%1$s</em>ничего не найлено.';
L10n::$locales['by'] = 'кем';
L10n::$locales['here'] = 'здесь';
L10n::$locales['in'] = 'в';
L10n::$locales['next entries'] = 'следующие записи';
L10n::$locales['no attachments'] = 'нет вложений';
L10n::$locales['no comments'] = 'нет комментариев';
L10n::$locales['no reactions'] = 'нет реакций';
L10n::$locales['no trackbacks'] = 'нет трекбеков';
L10n::$locales['of'] = 'из';
L10n::$locales['on'] = 'в';
L10n::$locales['one attachment'] = 'Одно вложение';
L10n::$locales['one comment'] = 'Один комментарий';
L10n::$locales['one reaction'] = 'одна реакция';
L10n::$locales['one trackback'] = 'Один трекбек';
L10n::$locales['optional'] = 'необязательно';
L10n::$locales['page'] = 'страница';
L10n::$locales['preview'] = 'предпросмотр';
L10n::$locales['previous entries'] = 'предыдущие записи';
L10n::$locales['reactions'] = 'реакции';
L10n::$locales['send'] = 'отправить';
L10n::$locales['toDay'] = 'до дня';
